==> bitpay-3.1.2203.tar.gz: bitpay-3.1.2203/README.md <==
<img src="https://bitpay.com/_nuxt/img/bitpay-logo-blue.1c0494b.svg" width="150">

# BitPay Python Client
[![GitHub license](https://img.shields.io/badge/license-MIT-blue.svg?style=flat-square)](https://raw.githubusercontent.com/bitpay/python-bitpay-client/master/LICENSE)
[![Travis](https://img.shields.io/travis/bitpay/bitpay-python.svg?style=flat-square)](https://travis-ci.org/bitpay/python-bitpay-client)
[![PyPI](https://img.shields.io/pypi/v/bitpay.svg?style=flat-square)](https://pypi.python.org/pypi?%3Aaction=pkg_edit&name=bitpay)
[![PyPI](https://img.shields.io/pypi/v/bitpay.svg?style=flat-square)](https://pypi.org/project/bitpay)
[![Supported Python versions](https://pypip.in/py_versions/bitpay/badge.svg?style=flat-square)](https://pypi.org/project/bitpay)
[![Scrutinizer](https://img.shields.io/scrutinizer/g/bitpay/bitpay-python.svg?style=flat-square)](https://scrutinizer-ci.com/g/bitpay/python-bitpay-client/)
[![Coveralls](https://img.shields.io/coveralls/bitpay/bitpay-python.svg?style=flat-square)](https://coveralls.io/r/bitpay/python-bitpay-client)

Full implementation of the BitPay Payment Gateway. This library implements BitPay's [Cryptographically Secure RESTful API](https://bitpay.com/api).

Our Lite version will most likely be all you need to integrate to your site, available [here](https://github.com/bitpay/python-bitpay-light-client)

## Getting Started

To get up and running with our Python library quickly, follow [The GUIDE](https://github.com/bitpay/python-bitpay-client/blob/master/GUIDE.md)

## Support

* https://github.com/bitpay/python-bitpay-client/issues
* https://support.bitpay.com

## Contribute

To contribute to this project, please fork and submit a pull request.

## License

MIT License

Copyright (c) 2021 BitPay

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

==> bitpay-7.0.4.tar.gz: bitpay-7.0.4/README.md <==
<img src="https://bitpay.com/_nuxt/img/bitpay-logo-blue.1c0494b.svg" width="150">

# BitPay Python Client
[![GitHub license](https://img.shields.io/badge/license-MIT-blue.svg?style=flat-square)](https://raw.githubusercontent.com/bitpay/python-bitpay-client/master/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/bitpay.svg?style=flat-square)](https://pypi.org/project/bitpay)

Full implementation of the BitPay Payment Gateway. This library implements BitPay's [Cryptographically Secure RESTful API](https://developer.bitpay.com/reference/concepts).

## Support

* https://github.com/bitpay/python-bitpay-client/issues
* https://support.bitpay.com

## Contribute

To contribute to this project, please fork and submit a pull request.

## License

MIT License

Copyright (c) 2021 BitPay

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
